@@ -33,7 +33,7 @@ def acor(data, maxlag=10):
     return _acor.acor(np.array(data), maxlag)
 
 
-def function(data):
+def function(data, maxt=None):
     """
     Calculate the autocorrelation function for a 1D time series.
 
@@ -48,11 +48,20 @@ def function(data):
         An autocorrelation function.
 
     """
-    N = len(data)
-    mu = np.mean(data)
-    result = np.zeros_like(data)
-
-    for t in xrange(N):
-        result[t] = np.mean((data[:N - t] - mu) * (data[t:] - mu))
-
+    data = np.atleast_1d(data)
+    assert len(np.shape(data)) == 1, \
+        "The autocorrelation function can only by computed " \
+        + "on a 1D time series."
+    if maxt is None:
+        maxt = len(data)
+    result = np.zeros(maxt, dtype=float)
+    _acor.function(np.array(data, dtype=float), result)
     return result / result[0]
+
+if __name__ == "__main__":
+    import time
+    x = np.random.randn(499500)
+
+    s = time.time()
+    print function(x, 20000).shape
+    print time.time() - s
